#[repr(C, u8)]pub enum LinkParamValueOrNone {
None,
Specified(OwnedStr),
}Expand description
A struct to hold a specific ‘
Variants
None
Handles the case when no value is provided at all: param(–a)
Specified(OwnedStr)
Handles the cases for provided, or provided but empty, e.g. param(–a, blue) and param(–a, )