#[repr(transparent)]pub struct LinkParamValue(pub OwnedStr);Expand description
A struct to hold a specific ‘
Tuple Fields
0: OwnedStrTrait Implementations
Sourceimpl Clone for LinkParamValue
impl Clone for LinkParamValue
Sourcefn clone(&self) -> LinkParamValue
fn clone(&self) -> LinkParamValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinkParamValue
impl Debug for LinkParamValue
Sourceimpl MallocSizeOf for LinkParamValue
impl MallocSizeOf for LinkParamValue
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for LinkParamValue
impl PartialEq for LinkParamValue
Sourcefn eq(&self, other: &LinkParamValue) -> bool
fn eq(&self, other: &LinkParamValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SpecifiedValueInfo for LinkParamValue
impl SpecifiedValueInfo for LinkParamValue
Sourceconst SUPPORTED_TYPES: u8
const SUPPORTED_TYPES: u8
Supported CssTypes by the given value type. Read more
Sourceimpl ToComputedValue for LinkParamValue
impl ToComputedValue for LinkParamValue
Sourcetype ComputedValue = LinkParamValue
type ComputedValue = LinkParamValue
The computed value type we’re going to be converted to.
Sourcefn from_computed_value(from: &Self::ComputedValue) -> Self
fn from_computed_value(from: &Self::ComputedValue) -> Self
Convert a computed value to specified value form. Read more
Sourcefn to_computed_value(&self, context: &Context<'_>) -> Self::ComputedValue
fn to_computed_value(&self, context: &Context<'_>) -> Self::ComputedValue
Convert a specified value to a computed value, using itself and the data
inside the
Context.Sourceimpl ToResolvedValue for LinkParamValue
impl ToResolvedValue for LinkParamValue
Sourcetype ResolvedValue = LinkParamValue
type ResolvedValue = LinkParamValue
The resolved value type we’re going to be converted to.
Sourcefn from_resolved_value(from: Self::ResolvedValue) -> Self
fn from_resolved_value(from: Self::ResolvedValue) -> Self
Convert a resolved value to resolved value form.
Sourcefn to_resolved_value(self, context: &Context<'_>) -> Self::ResolvedValue
fn to_resolved_value(self, context: &Context<'_>) -> Self::ResolvedValue
Convert a resolved value to a resolved value.
Sourceimpl ToShmem for LinkParamValue
impl ToShmem for LinkParamValue
impl StructuralPartialEq for LinkParamValue